@@ -1,5 +1,5 @@
 #!/bin/sh
-##                            Time-stamp: <2004-08-07 23:37:22 cyamauch>
+##                            Time-stamp: <2008-07-06 14:41:59 kojima>
 
 # 2004-08-07 added support of "AlwaysCore" mouse setting for laptop.
 # 2004-08-04 added support for Plamo-4.01.
@@ -132,6 +132,7 @@ XMODULE=""
 XDEPTH=""
 #XMOUSE="gpm"
 XMOUSE=""
+XSERVER="xorg"
 DEVUSBMOUSE="/dev/input/mice"
 DEVPS2MOUSE="/dev/psaux"
 
@@ -170,14 +171,19 @@ CDPLAMO_CHK="`ls /usr/lib/setup/ | grep cdplamo`"
 
 TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
 
-LINE_BEGIN=`/usr/X11R6/bin/scanpci -v|nl -b a|grep '	  CLASS     0x03 0x'|awk 'NR==1{print $1}'`
+#LINE_BEGIN=`/usr/X11R7/bin/scanpci -v|nl -b a|grep '	  CLASS     0x03 0x'|awk 'NR==1{print $1}'`
+# 
+# Ƕ xserver ϼǥϡɥǧscanpci פˤʤäƤΤǡ
+# ɥ饤ин xserver ˤ餻뤳Ȥˤ
+
+LINE_BEGIN=''
 if [ "$LINE_BEGIN" = "" ] ; then
   echo -n "" > $TMPFILE
 else
   LINE_BEGIN=`expr $LINE_BEGIN - 4`
   LINE_END=`expr $LINE_BEGIN + 10`
   #echo $LINE_BEGIN
-  /usr/X11R6/bin/scanpci -v | awk ${LINE_BEGIN}'<=NR&&NR<='${LINE_END}'{print}' > $TMPFILE
+  /usr/X11R7/bin/scanpci -v | awk ${LINE_BEGIN}'<=NR&&NR<='${LINE_END}'{print}' > $TMPFILE
   #echo $SCANRESULT
   if [ "`cat $TMPFILE | awk 'NR==1{print}'`" = "" ] ; then
     set_vendor_and_device `cat $TMPFILE | awk 'NR==2{print $9" "$11}'`
@@ -210,7 +216,9 @@ done
 for i in $ARGS ; do
   ARG=`echo $i|sed -e 's/=.*//g'`
   VAL=`echo $i|sed -e 's/.*=//g'`
-  if [ "$ARG" = "xscreen" ] ; then
+  if [ "$ARG" = "xserver" ] ; then
+    XSERVER="$VAL"
+  elif [ "$ARG" = "xscreen" ] ; then
     XSCREEN="$VAL"
   elif [ "$ARG" = "xmodule" ] ; then
     XMODULE="$VAL"
@@ -237,6 +245,19 @@ for i in $ARGS ; do
   fi
 done
 
+if [ "$XSERVER" = "xorg" ]; then
+  X11DIR=/usr/X11R7
+  CONFIGOPT="-config"
+  ( cd /usr/X11R7/bin ; rm -f X )
+  ( cd /usr/X11R7/bin ; ln -s Xorg X )
+else
+  X11DIR=/usr/XFree86
+  CONFIGOPT="-xf86config"
+  ( cd /usr/X11R7/bin ; rm -f X )
+  ( cd /usr/X11R7/bin ; ln -s ../../XFree86/bin/XFree86 X )
+fi
+PATH=$X11DIR:$PATH
+
 if [ "$CDPLAMO_CHK" != "" ] ; then
   #USBMOUSE_CHK="`/sbin/lsmod | awk '{print $1}' | grep '^usbmouse'`"
   if [ -f /proc/bus/usb/devices ] ; then
@@ -324,15 +345,28 @@ fi
 #echo $WIDEMODE $MODENUM
 #exit
 
-TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
+# TMPFILE=`mktemp /tmp/tmp_xfplamoconfig_$$.XXXXXX`
+TMPDRIVER=`mktemp /tmp/tmp_tmpdriver_$$.XXXXXX`
 
-if [ "$VENDOR" != "" ] ; then
-  if [ "$CARD_VENDOR" != "" ] ; then
-    /usr/X11R6/bin/getconfig -I /usr/X11R6/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION 1> $TMPFILE 2>/dev/null
-  else
-    /usr/X11R6/bin/getconfig -I /usr/X11R6/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION -s $CARD_VENDOR -b $CARD 1> $TMPFILE 2>/dev/null
-  fi
+# if [ "$VENDOR" != "" ] ; then
+#  if [ "$CARD_VENDOR" != "" ] ; then
+#    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION 1> $TMPFILE 2>/dev/null
+#  else
+#    $X11DIR/bin/getconfig -I $X11DIR/lib/X11/getconfig -v $VENDOR -d $DEVICE -r $REVISION -s $CARD_VENDOR -b $CARD 1> $TMPFILE 2>/dev/null
+#  fi
+#fi
+
+moved_flag=0
+if [ -f /etc/X11/xorg.conf ]; then
+    mv /etc/X11/xorg.conf /etc/X11/xorg.conf.orig
+    moved_flag=1
 fi
+newdriver=`/usr/X11R7/bin/Xorg -probeonly 2>&1 | grep 'New driver' | cut -d' ' -f4 | sed -e 's/"//g'`
+echo $newdriver > $TMPDRIVER
+if [ $moved_flag = "1" ]; then
+    mv /etc/X11/xorg.conf.orig /etc/X11/xorg.conf
+fi
+
 
 # 855GM ʥޥ VBIOS ٤֤ʤåץȥåץޥѤк
 # See http://wiki.0-24.jp/?Linux%2FY2%A4%C7SXGA%2B
@@ -341,19 +375,19 @@ if [ "$CDPLAMO_CHK" != "" -a "$LCD_CHK" != "" -a "$NO855TEST" = "" ]; then
   if [ "$VENDOR" = "0x8086" -a "$DEVICE" = "0x3582" ]; then
     if [ "$XSCREEN" = "" ]; then
       $0 --no855test > /etc/X11/XF86Config.test
-      /usr/X11R6/bin/X -probeonly -xf86config /etc/X11/XF86Config.test 1> /dev/null 2> /dev/null
+      $X11DIR/bin/X -probeonly $CONFIGOPT /etc/X11/XF86Config.test 1> /dev/null 2> /dev/null
       LFP_RESOLUTION="`cat /var/log/XFree86.0.log | grep 'Size of device LFP (local flat panel) is' | sed -e 's/.*is //g' -e 's/ //g' | awk 'NR==1'`"
     else
       LFP_RESOLUTION="$XSCREEN"
     fi
     if [ "$LFP_RESOLUTION" != "" ]; then
       TMP855FILE=`mktemp /tmp/tmp855_xfplamoconfig_$$.XXXXXX`
-      /usr/X11R6/bin/855resolution -l | grep 'Mode ' > $TMP855FILE
+      /usr/bin/855resolution -l | grep 'Mode ' > $TMP855FILE
       MODE_CHK="`cat $TMP855FILE | grep \" ${LFP_RESOLUTION},\"`"
       if [ "$MODE_CHK" = "" ]; then
         MODE_LIST="`cat $TMP855FILE | grep ' 800x600,' | awk '{print $2}'`"
         for i in $MODE_LIST ; do
-          /usr/X11R6/bin/855resolution $i `echo $LFP_RESOLUTION | tr 'x' ' '` 1> /dev/null
+          /usr/bin/855resolution $i `echo $LFP_RESOLUTION | tr 'x' ' '` 1> /dev/null
         done
       fi
       rm -f $TMP855FILE
@@ -375,35 +409,35 @@ cat <<EOF
 EndSection
 
 Section "Files"
-        RgbPath      "/usr/X11R6/lib/X11/rgb"
-        ModulePath   "/usr/X11R6/lib/modules"
-        FontPath     "/usr/X11R6/lib/X11/fonts/local/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/75dpi/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/100dpi/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/TrueType/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/ghostscript/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Type1/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Bitmap/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/misc/:unscaled"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Speedo/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/freefont/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/CID/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/75dpi/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/100dpi/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/Bitmap/"
-        FontPath     "/usr/X11R6/lib/X11/fonts/misc/"
+        #RgbPath      "$X11DIR/lib/X11/rgb"
+        #ModulePath   "$X11DIR/lib/modules"
+	FontPath     "unix/:7100"
+        # FontPath     "/usr/X11R7/lib/X11/fonts/local/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/misc/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/75dpi/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/100dpi/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Bitmap/:unscaled"
+        FontPath     "/usr/X11R7/lib/X11/fonts/TTF/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/TrueType/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Type1/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Speedo/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/freefont/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/ghostscript/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/misc/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/75dpi/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/100dpi/"
+        FontPath     "/usr/X11R7/lib/X11/fonts/Bitmap/"
+        # FontPath     "/usr/X11R7/lib/X11/fonts/CID/"
 EndSection
 
 Section "Module"
         Load  "freetype"
         Load  "type1"
-        Load  "speedo"
         Load  "extmod"
         Load  "glx"
-        Load  "dri"
         Load  "dbe"
-        #Load  "record"
-        #Load  "xtrap"
+        Load  "record"
+        Load  "xtrap"
 EndSection
 
 EOF
@@ -544,7 +578,8 @@ echo '        Identifier  "Card0"'
 if [ "$XMODULE" = "" ] ; then
   echo -n '        Driver      '
   echo -n '"'
-  GETCONF_MODULE="`cat $TMPFILE | awk 'NR==1{print $1}'`"
+  #GETCONF_MODULE="`cat $TMPFILE | awk 'NR==1{print $1}'`"
+  GETCONF_MODULE="`cat $TMPDRIVER`"
   if [ "$GETCONF_MODULE" = "" ] ; then
     echo -n "$FALLBACK_XMODULE"
   else
@@ -572,8 +607,8 @@ if [ "$LCD_CHK" != "" -a "$XSCREEN" = "" ]; then
   echo '        Identifier "Screen0"'
   echo '        Device     "Card0"'
   echo '        Monitor    "Monitor0"'
-  echo '        Option     "NoDoublescan" "True"'
-  echo '        Option     "NoInterlace" "True"'
+#  echo '        Option     "NoDoublescan" "True"'
+#  echo '        Option     "NoInterlace" "True"'
   echo 'EndSection'
   echo ''
 else
@@ -622,7 +657,11 @@ Section "DRI"
         Mode 0666
 EndSection
 
+Section "ServerFlags"
+ Option "AutoAddDevices" "false"
+EndSection
+
 EOF
 
-rm -f $TMPFILE
+ rm -f $TMPFILE $TMPDRIVER
 
